mathics_scanner: Character Tables and Tokenizer for Mathics and the Wolfram Language
====================================================================================

Description
-----------

Character Tables and Tokenizer for Mathics and the Wolfram Language

License
-------

GPL-3.0-only

Upstream Contact
----------------

https://pypi.org/project/Mathics-Scanner/

